@@ -28,5 +28,6 @@ def reformat(msg):
                                 encoding = 'utf-8')
                 msg.set_payload(help_text)
                 return True
-            except KeyError: pass
+            except KeyError: 
+                pass
     return False
